"""
DuckClaw 🦆🤖 — Powerful AI, built for you, built with you, built securely.
Local-first personal AI assistant with a 4-tier permission engine.
"""

import os
os.environ.setdefault("ANONYMIZED_TELEMETRY", "False")
os.environ.setdefault("CHROMA_TELEMETRY", "False")

__version__ = "0.1.1"
__author__ = "DuckClaw Contributors"
